==> zhongyan-manage-service-api-3.0.31-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/datav/RemoteDatavProductService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.datav;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.KvDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.plan.ActivityReachDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.CigarettePriceDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.CigarettePurchasersDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.DataVTempDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.YearSaleTargetDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.strategy.ScanDataDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.strategy.ScanPvDataDto;

import java.util.List;

/**
 * @Author: nongfu
 * @Date: 2023/5/23-21:59
 * @Description:
 */
@AdvancedFeignClient
public interface RemoteDatavProductService {

    /**
     * 通过商品规格 和城市查询code
     * @param tobaId 品规id
     * @param code
     * @return
     */
    YearSaleTargetDto getSaleAndTargetByCodeAndCar(String tobaId,String code,String type);


    /**
     * 获取零售户数和可订货数
     * @param tobaId
     * @param code
     * @return
     */
    List<DataVTempDto> getCigarettePurchasers(String tobaId, String code, String type);


    /**
     * 查询价格与存销比
     * @param tobaId
     * @param code
     * @return
     */
    List<DataVTempDto> getCigarettePrice(String tobaId, String code,String type);

    /**
     * 扫码统计
     * @return
     */
    ScanDataDTO getActivityReachData();


    /**
     * 扫码数据通过品规id
     * @return
     */
    List<KvDTO> getActivityReachDataByTobaId(String tobaId);


    void  testTask(Integer type);

}

==> zhongyan-manage-service-api-3.0.36-sources.jar: cn/com/duiba/cloud/manage/service/api/remoteservice/datav/RemoteDatavProductService.java <==
package cn.com.duiba.cloud.manage.service.api.remoteservice.datav;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.KvDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.plan.ActivityReachDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.CigarettePriceDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.CigarettePurchasersDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.DataVTempDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.product.YearSaleTargetDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.strategy.DatavCigaretteSaleVolumeDto;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.strategy.ScanDataDTO;
import cn.com.duiba.cloud.manage.service.api.model.dto.datav.strategy.ScanPvDataDto;

import java.util.List;

/**
 * @Author: nongfu
 * @Date: 2023/5/23-21:59
 * @Description:
 */
@AdvancedFeignClient
public interface RemoteDatavProductService {

    /**
     * 通过商品规格 和城市查询code
     * @param tobaId 品规id
     * @param code
     * @return
     */
    YearSaleTargetDto getSaleAndTargetByCodeAndCar(String tobaId,String code,String type);


    /**
     * 获取零售户数和可订货数
     * @param tobaId
     * @param code
     * @return
     */
    List<DataVTempDto> getCigarettePurchasers(String tobaId, String code, String type);


    /**
     * 查询价格与存销比
     * @param tobaId
     * @param code
     * @return
     */
    List<DataVTempDto> getCigarettePrice(String tobaId, String code,String type);

    /**
     * 扫码统计
     * @return
     */
    ScanDataDTO getActivityReachData();


    /**
     * 扫码数据通过品规id
     * @return
     */
    List<KvDTO> getActivityReachDataByTobaId(String tobaId);


    void  testTask(Integer type);

    /**
     * 插入销量值
     * @param list
     */
   void insertTargetData( List<DatavCigaretteSaleVolumeDto> list);

}
